APPT = "appt"
APPT_OTHER = "other_routine_appt"
COMMUNITY_CLINIC = "community_clinic"
GTE_3HRS = "gte_3hr"
MISSED_VISIT_ACTION = "missed_visit_action"
NOT_SCHEDULED_FOR_FACILITY = "NOT_SCHEDULED_FOR_FACILITY"
NURSE = "nurse"
SITTING = "sitting"
VERTICAL = "vertical"
VIT_B_FOLIC_ACID = "vitamin_b_folic_acid"
