# Generated by Django 4.2.3 on 2023-08-15 18:50

from django.db import migrations, models
import edc_action_item.managers
import edc_sites.model_mixins


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0007_aeinitial_ae_classification_as_text_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="deathreporttmgsecond",
            options={},
        ),
        migrations.AlterModelOptions(
            name="historicaldeathreporttmgsecond",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical death report tmg second",
                "verbose_name_plural": "historical death report tmg seconds",
            },
        ),
        migrations.AlterModelManagers(
            name="aeinitial",
            managers=[
                ("on_site", edc_sites.model_mixins.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="ae_action_classification",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="ae_cause",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="ae_cause_other",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="ae_study_relation_possibility",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="sae",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="sae_reason",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="susar",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="susar_reported",
        ),
        migrations.RemoveField(
            model_name="aeinitial",
            name="tmg_report_datetime",
        ),
        migrations.RemoveField(
            model_name="deathreport",
            name="secondary_cause_of_death",
        ),
        migrations.RemoveField(
            model_name="deathreport",
            name="secondary_cause_of_death_other",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="ae_action_classification",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="ae_cause",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="ae_cause_other",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="ae_study_relation_possibility",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="sae",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="sae_reason",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="susar",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="susar_reported",
        ),
        migrations.RemoveField(
            model_name="historicalaeinitial",
            name="tmg_report_datetime",
        ),
        migrations.RemoveField(
            model_name="historicaldeathreport",
            name="secondary_cause_of_death",
        ),
        migrations.RemoveField(
            model_name="historicaldeathreport",
            name="secondary_cause_of_death_other",
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="study_drug_relation",
            field=models.CharField(
                editable=False,
                max_length=25,
                null=True,
                verbose_name="Relation to study drug:",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="cause_of_death",
            field=models.TextField(
                help_text="Main cause of death in the opinion of the local study doctor and local PI",
                null=True,
                verbose_name="Main cause of death",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="study_drug_relation",
            field=models.CharField(
                editable=False,
                max_length=25,
                null=True,
                verbose_name="Relation to study drug:",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="cause_of_death",
            field=models.TextField(
                help_text="Main cause of death in the opinion of the local study doctor and local PI",
                null=True,
                verbose_name="Main cause of death",
            ),
        ),
    ]
