# Generated by Django 4.2.3 on 2023-08-02 23:56

from django.db import migrations, models
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0068_remove_historicalhba1cresult_history_user_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.CharField(
                choices=[
                    (
                        "1",
                        "Chief executives, managers, senior officials and legislators",
                    ),
                    ("2", "Professionals, technicians and associate professionals"),
                    ("4", "Clerks"),
                    ("5", "Service workers and shop sale workers"),
                    ("6", "Skilled agricultural and fishery workers"),
                    ("7", "Unskilled agricultural and fishery workers"),
                    ("8", "Craft and related workers"),
                    ("9", "Plant and machine operators and assemblers"),
                    ("10", "Elementary occupations"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=100,
                null=True,
                verbose_name="If OTHER type of employment, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_employment_type",
            field=models.CharField(
                choices=[
                    (
                        "1",
                        "Chief executives, managers, senior officials and legislators",
                    ),
                    ("2", "Professionals, technicians and associate professionals"),
                    ("4", "Clerks"),
                    ("5", "Service workers and shop sale workers"),
                    ("6", "Skilled agricultural and fishery workers"),
                    ("7", "Unskilled agricultural and fishery workers"),
                    ("8", "Craft and related workers"),
                    ("9", "Plant and machine operators and assemblers"),
                    ("10", "Elementary occupations"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your type of employment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.CharField(
                choices=[
                    (
                        "1",
                        "Chief executives, managers, senior officials and legislators",
                    ),
                    ("2", "Professionals, technicians and associate professionals"),
                    ("4", "Clerks"),
                    ("5", "Service workers and shop sale workers"),
                    ("6", "Skilled agricultural and fishery workers"),
                    ("7", "Unskilled agricultural and fishery workers"),
                    ("8", "Craft and related workers"),
                    ("9", "Plant and machine operators and assemblers"),
                    ("10", "Elementary occupations"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=100,
                null=True,
                verbose_name="If OTHER type of employment, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_employment_type",
            field=models.CharField(
                choices=[
                    (
                        "1",
                        "Chief executives, managers, senior officials and legislators",
                    ),
                    ("2", "Professionals, technicians and associate professionals"),
                    ("4", "Clerks"),
                    ("5", "Service workers and shop sale workers"),
                    ("6", "Skilled agricultural and fishery workers"),
                    ("7", "Unskilled agricultural and fishery workers"),
                    ("8", "Craft and related workers"),
                    ("9", "Plant and machine operators and assemblers"),
                    ("10", "Elementary occupations"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your type of employment?",
            ),
        ),
    ]
