# Generated by Django 4.2.3 on 2023-07-11 02:28

from django.db import migrations, models
import edc_model.models.fields.duration
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0052_alter_bloodresultsfbc_managers_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhivreview",
            name="arv_initiated",
        ),
        migrations.RemoveField(
            model_name="historicalhivreview",
            name="arv_initiation_actual_date",
        ),
        migrations.RemoveField(
            model_name="hivreview",
            name="arv_initiated",
        ),
        migrations.RemoveField(
            model_name="hivreview",
            name="arv_initiation_actual_date",
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="rx_init_ago",
            field=edc_model.models.fields.duration.DurationYMDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started antiretroviral therapy (ART)?",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="rx_init_ago",
            field=edc_model.models.fields.duration.DurationYMDField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was antiretroviral therapy (ART) start date estimated?",
            ),
        ),
    ]
