 <a id="subject_dashboard_{{ subject_identifier }}" class="btn btn-primary btn-sm" role="button"
title="{{ title }}" href="{{ subject_dashboard_href }}">
<i class="fas fa-user-circle fa-sm"></i> Dashboard  <i class="fas fa-share"></i></a>
