{% comment %}Button to add a subject refusal{% endcomment %}

<a id="consentrefusal_change_{{ screening_identifier }}"
 	title="{{ title }}"
    class="btn btn-default btn-sm" data-toggle="tooltip"  data-placement="right"
        {% if perms.intecomm_screening.view_consentrefusal or perms.intecomm_screening.change_consentrefusal %}
        	href="{{ href }}"
        {% else %}
        	disabled
        {% endif %}>
     Refusal
</a>
