# Generated by Django 4.2.3 on 2023-08-03 15:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_he", "0004_historicalemployment_historicaleducation_employment_and_more"),
        ("intecomm_subject", "0080_auto_20230803_1726"),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            old_name="hoh_education",
            new_name="hoh_education_old",
        ),
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            old_name="hoh_employment_type",
            new_name="hoh_employment_type_old",
        ),
        migrations.RenameField(
            model_name="healtheconomicspatient",
            old_name="pat_employment_type",
            new_name="pat_employment_type_old",
        ),
        migrations.RenameField(
            model_name="healtheconomicspatient",
            old_name="pat_education",
            new_name="pat_education_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            old_name="hoh_education",
            new_name="hoh_education_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            old_name="hoh_employment_type",
            new_name="hoh_employment_type_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicspatient",
            old_name="pat_employment_type",
            new_name="pat_employment_type_old",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicspatient",
            old_name="pat_education",
            new_name="pat_education_old",
        ),
    ]
