# Generated by Django 4.2.3 on 2023-08-03 15:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0083_auto_20230803_1828"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                max_length=25, verbose_name="Household head’s type of employment"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                max_length=25, verbose_name="What is the household head’s ethnic background?"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_education_old",
            field=models.CharField(
                max_length=25, verbose_name="Highest level of education completed?"
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_employment_type_old",
            field=models.CharField(
                max_length=25, verbose_name="What is your type of employment?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                max_length=25, verbose_name="Household head’s type of employment"
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                max_length=25, verbose_name="What is the household head’s ethnic background?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_education_old",
            field=models.CharField(
                max_length=25, verbose_name="Highest level of education completed?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_employment_type_old",
            field=models.CharField(
                max_length=25, verbose_name="What is your type of employment?"
            ),
        ),
    ]
