# Generated by Django 4.1.2 on 2023-02-28 00:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0014_alter_historicalotherbaselinedata_activity_combined_mn_avg_day_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results at present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_reportable",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                help_text="If YES, this value will open Adverse Event Form. Grade 3 and 4 results present at baseline or continuing from baseline not included",
                max_length=25,
                verbose_name="If any results are abnormal, are results within grade 3 or above?",
            ),
        ),
    ]
