# Generated by Django 4.2.3 on 2023-07-18 01:35

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0057_rename_smoker_current_duration_historicalotherbaselinedata_smoker_duration_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="external_remittance_currency",
            new_name="external_remit_currency",
        ),
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="external_remittance_currency_other",
            new_name="external_remit_currency_other",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="external_remittance_currency",
            new_name="external_remit_currency",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="external_remittance_currency_other",
            new_name="external_remit_currency_other",
        ),
    ]
