# Generated by Django 4.2.3 on 2023-08-03 00:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("edc_he", "0003_ethnicities_extra_value_and_more"),
        ("intecomm_subject", "0070_healtheconomicshouseholdhead_hoh_ethnicity_old_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.ethnicities",
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.ethnicities",
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
    ]
