# Generated by Django 4.1.7 on 2023-04-04 00:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0005_htnmanagement_and_more"),
        ("intecomm_subject", "0020_remove_historicalhtninitialreview_managed_by_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="htninitialreview",
            name="managed_by",
            field=models.ManyToManyField(
                to="intecomm_lists.htnmanagement",
                verbose_name="How is the patient's hypertension managed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="managed_by_old",
            field=models.CharField(
                choices=[
                    ("drugs", "Drugs / Medicine"),
                    ("diet_lifestyle", "Diet and lifestyle alone"),
                ],
                default="N/A",
                help_text="If patient is taking medication, complete the Drug Refill CRF.",
                max_length=15,
                verbose_name="How is the patient's hypertension managed?",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="managed_by_old",
            field=models.CharField(
                choices=[
                    ("drugs", "Drugs / Medicine"),
                    ("diet_lifestyle", "Diet and lifestyle alone"),
                ],
                default="N/A",
                help_text="If patient is taking medication, complete the Drug Refill CRF.",
                max_length=15,
                verbose_name="How is the patient's hypertension managed?",
            ),
        ),
    ]
