# Generated by Django 4.2.1 on 2023-05-23 23:18

from django.db import migrations, models
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0043_healtheconomicshouseholdhead_relationship_to_hoh_other_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER education, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER ethnic background, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_insurance_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True, max_length=35, null=True, verbose_name="If OTHER, specify ..."
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER religious orientation, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_education_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER education, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER ethnic background, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_insurance_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True, max_length=35, null=True, verbose_name="If OTHER, specify ..."
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If OTHER religious orientation, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the household head a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.CharField(
                choices=[
                    ("1", "1. Legislators, administrators, and managers"),
                    ("2", "2. Professionals"),
                    ("3", "3. Technicians and associate professionals"),
                    ("4", "4. Clerks"),
                    ("5", "5. Service workers and shop sale workers"),
                    ("6", "6. Skilled agricultural and fishery workers"),
                    ("7", "7. Unskilled agricultural and fishery workers"),
                    ("8", "8. Craft and related workers"),
                    ("9", "9. Plant and machine operators and assemblers"),
                    ("10", "10. Elementary occupations"),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "1. Never Married (but not co-habiting)"),
                    ("2", "2. Co-habiting"),
                    ("3", "3. Currently Married"),
                    ("4", "4. Separated/Divorced"),
                    ("5", "5. Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s marital status",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_employment_type",
            field=models.CharField(
                choices=[
                    ("1", "1. Legislators, administrators, and managers"),
                    ("2", "2. Professionals"),
                    ("3", "3. Technicians and associate professionals"),
                    ("4", "4. Clerks"),
                    ("5", "5. Service workers and shop sale workers"),
                    ("6", "6. Skilled agricultural and fishery workers"),
                    ("7", "7. Unskilled agricultural and fishery workers"),
                    ("8", "8. Craft and related workers"),
                    ("9", "9. Plant and machine operators and assemblers"),
                    ("10", "10. Elementary occupations"),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your type of employment?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "1. Never Married (but not co-habiting)"),
                    ("2", "2. Co-habiting"),
                    ("3", "3. Currently Married"),
                    ("4", "4. Separated/Divorced"),
                    ("5", "5. Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your marital status?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the household head a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.CharField(
                choices=[
                    ("1", "1. Legislators, administrators, and managers"),
                    ("2", "2. Professionals"),
                    ("3", "3. Technicians and associate professionals"),
                    ("4", "4. Clerks"),
                    ("5", "5. Service workers and shop sale workers"),
                    ("6", "6. Skilled agricultural and fishery workers"),
                    ("7", "7. Unskilled agricultural and fishery workers"),
                    ("8", "8. Craft and related workers"),
                    ("9", "9. Plant and machine operators and assemblers"),
                    ("10", "10. Elementary occupations"),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "1. Never Married (but not co-habiting)"),
                    ("2", "2. Co-habiting"),
                    ("3", "3. Currently Married"),
                    ("4", "4. Separated/Divorced"),
                    ("5", "5. Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="Household head’s marital status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_employment_type",
            field=models.CharField(
                choices=[
                    ("1", "1. Legislators, administrators, and managers"),
                    ("2", "2. Professionals"),
                    ("3", "3. Technicians and associate professionals"),
                    ("4", "4. Clerks"),
                    ("5", "5. Service workers and shop sale workers"),
                    ("6", "6. Skilled agricultural and fishery workers"),
                    ("7", "7. Unskilled agricultural and fishery workers"),
                    ("8", "8. Craft and related workers"),
                    ("9", "9. Plant and machine operators and assemblers"),
                    ("10", "10. Elementary occupations"),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your type of employment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "1. Never Married (but not co-habiting)"),
                    ("2", "2. Co-habiting"),
                    ("3", "3. Currently Married"),
                    ("4", "4. Separated/Divorced"),
                    ("5", "5. Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don’t know"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                verbose_name="What is your marital status?",
            ),
        ),
    ]
