# Generated by Django 4.1.7 on 2023-04-19 02:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0018_alter_historicalpatientlog_age_in_years_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthfacility",
            name="fri",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="mon",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="sat",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="thu",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="tue",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="healthfacility",
            name="wed",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="fri",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="mon",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="sat",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="thu",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="tue",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhealthfacility",
            name="wed",
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
    ]
