# Generated by Django 4.1.2 on 2022-11-22 20:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0009_historicalsubjectscreening_familiar_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientlog",
            name="age_in_years",
            field=models.IntegerField(default=0, verbose_name="Age"),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="patientlog",
            name="age_in_years",
            field=models.IntegerField(default=0, verbose_name="Age"),
            preserve_default=False,
        ),
    ]
