# Generated by Django 4.1.7 on 2023-05-11 16:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0011_alter_historicalpatientfollowupcall_respondent_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientgroup",
            name="status",
            field=models.CharField(
                choices=[
                    ("New", "New"),
                    ("recruiting", "Recruiting"),
                    ("COMPLETE", "Complete/Ready"),
                    ("in_followup", "In followup"),
                    ("dissolved", "Dissolved"),
                ],
                default="recruiting",
                help_text="Will reverted to 'Recruiting' if changes are made to the list of selected patients",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="patientgroup",
            name="status",
            field=models.CharField(
                choices=[
                    ("New", "New"),
                    ("recruiting", "Recruiting"),
                    ("COMPLETE", "Complete/Ready"),
                    ("in_followup", "In followup"),
                    ("dissolved", "Dissolved"),
                ],
                default="recruiting",
                help_text="Will reverted to 'Recruiting' if changes are made to the list of selected patients",
                max_length=25,
            ),
        ),
    ]
