# Generated by Django 4.2.3 on 2023-07-26 13:31

import edc_facility.model_mixins
import edc_sites.model_mixins
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_facility", "0002_auto_20230726_2030"),
        (
            "intecomm_screening",
            "0048_rename_historicalhealthfacility_historicaloldhealthfacility_and_more",
        ),
    ]

    operations = [
        migrations.RenameModel(
            old_name="HistoricalHealthFacility",
            new_name="HistoricalOldHealthFacility",
        ),
        migrations.RenameModel(
            old_name="HealthFacility",
            new_name="OldHealthFacility",
        ),
    ]
